@@ -636,7 +636,7 @@ gchar* atk_text_get_string_at_offset (AtkText *text,
  *
  * Gets the offset of the position of the caret (cursor).
  *
- * Returns: the character offset of the position of the caret or 0  if
+ * Returns: the character offset of the position of the caret or -1 if
  *          the caret is not located inside the element or in the case of
  *          any other failure.
  **/
@@ -652,7 +652,7 @@ atk_text_get_caret_offset (AtkText *text)
   if (iface->get_caret_offset)
     return (*(iface->get_caret_offset)) (text);
   else
-    return 0;
+    return -1;
 }
 
 /**
@@ -665,6 +665,9 @@ atk_text_get_caret_offset (AtkText *text)
  * @height: (out) (optional): Pointer for the height of the bounding box
  * @coords: specify whether coordinates are relative to the screen or widget window 
  *
+ * If the extent can not be obtained (e.g. missing support), all of x, y, width,
+ * height are set to -1.
+ *
  * Get the bounding box containing the glyph representing the character at 
  *     a particular text offset. 
  **/
@@ -700,10 +703,10 @@ atk_text_get_character_extents (AtkText *text,
   else
     real_height = &local_height;
 
-  *real_x = 0;
-  *real_y = 0;
-  *real_width = 0;
-  *real_height = 0;
+  *real_x = -1;
+  *real_y = -1;
+  *real_width = -1;
+  *real_height = -1;
 
   if (offset < 0)
     return;
@@ -781,11 +784,11 @@ atk_text_get_run_attributes (AtkText          *text,
  *attributes that can be returned. Note that other attributes may also be 
  *returned.
  *
- *Returns: (transfer full): an #AtkAttributeSet which contains the default values
- *          of attributes.  at @offset. this #atkattributeset should be freed by
+ *Returns: (transfer full): an #AtkAttributeSet which contains the default text
+ *          attributes for this #AtkText. This #AtkAttributeSet should be freed by
  *          a call to atk_attribute_set_free().
  */
-AtkAttributeSet* 
+AtkAttributeSet*
 atk_text_get_default_attributes (AtkText          *text)
 {
   AtkTextIface *iface;
@@ -1062,6 +1065,9 @@ atk_text_set_caret_offset (AtkText *text,
  *
  * Get the bounding box for text within the specified range.
  *
+ * If the extents can not be obtained (e.g. or missing support), the rectangle
+ * fields are set to -1.
+ *
  * Since: 1.3
  **/
 void
@@ -1081,6 +1087,13 @@ atk_text_get_range_extents (AtkText          *text,
 
   if (iface->get_range_extents)
     (*(iface->get_range_extents)) (text, start_offset, end_offset, coord_type, rect);
+  else
+    {
+      rect->x = -1;
+      rect->y = -1;
+      rect->width = -1;
+      rect->height = -1;
+    }
 }
 
 /**
@@ -1318,6 +1331,23 @@ atk_text_rectangle_union (AtkTextRectangle *src1,
 {
   gint dest_x, dest_y;
 
+  /*
+   * Some invocations of e.g. atk_text_get_character_extents
+   * may return "-1" rectangles for character positions without support for
+   * getting an extent. In that case we have to ignore them instead of using -1
+   * values in computations.
+   */
+  if (src1->width == -1)
+    {
+      *dest = *src2;
+      return;
+    }
+  if (src2->width == -1)
+    {
+      *dest = *src1;
+      return;
+    }
+
   dest_x = MIN (src1->x, src2->x);
   dest_y = MIN (src1->y, src2->y);
   dest->width = MAX (src1->x + src1->width, src2->x + src2->width) - dest_x;
@@ -1361,15 +1391,11 @@ atk_text_rectangle_contain (AtkTextRectangle *clip,
 /**
  * atk_text_scroll_substring_to:
  * @text: an #AtkText
- * @start_offset: start position
- * @end_offset: end position, or -1 for the end of the string.
+ * @start_offset: start offset in the @text
+ * @end_offset: end offset in the @text, or -1 for the end of the text.
  * @type: specify where the object should be made visible.
  *
- * Makes @text visible on the screen by scrolling all necessary parents.
- *
- * Contrary to atk_text_set_position, this does not actually move
- * @text in its parent, this only makes the parents scroll so that the
- * object shows up on the screen, given its current position within the parents.
+ * Makes a substring of @text visible on the screen by scrolling all necessary parents.
  *
  * Since: 2.32
  *
@@ -1395,15 +1421,15 @@ atk_text_scroll_substring_to (AtkText       *text,
 /**
  * atk_text_scroll_substring_to_point:
  * @text: an #AtkText
- * @start_offset: start position
- * @end_offset: end position, or -1 for the end of the string.
+ * @start_offset: start offset in the @text
+ * @end_offset: end offset in the @text, or -1 for the end of the text.
  * @coords: specify whether coordinates are relative to the screen or to the
  * parent object.
  * @x: x-position where to scroll to
  * @y: y-position where to scroll to
  *
- * Makes an object visible on the screen at a given position by scrolling all
- * necessary parents.
+ * Move the top-left of a substring of @text to a given position of the screen
+ * by scrolling all necessary parents.
  *
  * Since: 2.32
  *
